# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator
from airfly._vendor.airflow.models.skipmixin import SkipMixin


class PythonOperator(BaseOperator):
    python_callable: "typing.Callable"
    op_args: "typing.Union[typing.List, NoneType]"
    op_kwargs: "typing.Union[typing.Dict, NoneType]"
    templates_dict: "typing.Union[typing.Dict, NoneType]"
    templates_exts: "typing.Union[typing.List[str], NoneType]"


class PythonVirtualenvOperator(PythonOperator):
    python_callable: "typing.Callable"
    requirements: "typing.Union[typing.Iterable[str], NoneType]"
    python_version: "typing.Union[str, int, float, NoneType]"
    use_dill: "bool"
    system_site_packages: "bool"
    op_args: "typing.Union[typing.List, NoneType]"
    op_kwargs: "typing.Union[typing.Dict, NoneType]"
    string_args: "typing.Union[typing.Iterable[str], NoneType]"
    templates_dict: "typing.Union[typing.Dict, NoneType]"
    templates_exts: "typing.Union[typing.List[str], NoneType]"


class BranchPythonOperator(PythonOperator, SkipMixin):
    python_callable: "typing.Callable"
    op_args: "typing.Union[typing.List, NoneType]"
    op_kwargs: "typing.Union[typing.Dict, NoneType]"
    templates_dict: "typing.Union[typing.Dict, NoneType]"
    templates_exts: "typing.Union[typing.List[str], NoneType]"


class ShortCircuitOperator(PythonOperator, SkipMixin):
    python_callable: "typing.Callable"
    op_args: "typing.Union[typing.List, NoneType]"
    op_kwargs: "typing.Union[typing.Dict, NoneType]"
    templates_dict: "typing.Union[typing.Dict, NoneType]"
    templates_exts: "typing.Union[typing.List[str], NoneType]"
