# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.operators.compute import (
    ComputeEngineBaseOperator,
    ComputeEngineCopyInstanceTemplateOperator,
    ComputeEngineInstanceGroupUpdateManagerTemplateOperator,
    ComputeEngineSetMachineTypeOperator,
    ComputeEngineStartInstanceOperator,
    ComputeEngineStopInstanceOperator,
)


class GceBaseOperator(ComputeEngineBaseOperator):
    pass


class GceInstanceGroupManagerUpdateTemplateOperator(
    ComputeEngineInstanceGroupUpdateManagerTemplateOperator
):
    pass


class GceInstanceStartOperator(ComputeEngineStartInstanceOperator):
    pass


class GceInstanceStopOperator(ComputeEngineStopInstanceOperator):
    pass


class GceInstanceTemplateCopyOperator(ComputeEngineCopyInstanceTemplateOperator):
    pass


class GceSetMachineTypeOperator(ComputeEngineSetMachineTypeOperator):
    pass
