# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.operators.functions import (
    CloudFunctionDeleteFunctionOperator,
    CloudFunctionDeployFunctionOperator,
)


class GcfFunctionDeleteOperator(CloudFunctionDeleteFunctionOperator):
    pass


class GcfFunctionDeployOperator(CloudFunctionDeployFunctionOperator):
    pass
