# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.sensors.cloud_storage_transfer_service import (
    CloudDataTransferServiceJobStatusSensor,
)


class GCPTransferServiceWaitForJobStatusSensor(CloudDataTransferServiceJobStatusSensor):
    pass
