# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.apache.druid.transfers.hive_to_druid import (
    HiveToDruidOperator,
)


class HiveToDruidTransfer(HiveToDruidOperator):
    pass
