# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.mysql.transfers.presto_to_mysql import (
    PrestoToMySqlOperator,
)


class PrestoToMySqlTransfer(PrestoToMySqlOperator):
    pass
