# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.amazon.aws.transfers.s3_to_redshift import (
    S3ToRedshiftOperator,
)


class S3ToRedshiftTransfer(S3ToRedshiftOperator):
    pass
