# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.operators.text_to_speech import (
    CloudTextToSpeechSynthesizeOperator,
)


class GcpTextToSpeechSynthesizeOperator(CloudTextToSpeechSynthesizeOperator):
    pass
