# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.amazon.aws.sensors.sagemaker_base import (
    SageMakerBaseSensor,
)


class SageMakerTrainingSensor(SageMakerBaseSensor):
    job_name: "_empty"
    print_log: "_empty"
