# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class JiraOperator(BaseOperator):
    jira_method: "str"
    jira_conn_id: "str"
    jira_method_args: "typing.Union[dict, NoneType]"
    result_processor: "typing.Union[typing.Callable, NoneType]"
    get_jira_resource_method: "typing.Union[typing.Callable, NoneType]"
