# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.sensors.gcs import (
    GCSObjectExistenceSensor,
    GCSObjectsWithPrefixExistenceSensor,
    GCSObjectUpdateSensor,
    GCSUploadSessionCompleteSensor,
)


class GoogleCloudStorageObjectSensor(GCSObjectExistenceSensor):
    pass


class GoogleCloudStorageObjectUpdatedSensor(GCSObjectUpdateSensor):
    pass


class GoogleCloudStoragePrefixSensor(GCSObjectsWithPrefixExistenceSensor):
    pass


class GoogleCloudStorageUploadSessionCompleteSensor(GCSUploadSessionCompleteSensor):
    pass
