# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.decorators.base import DecoratedOperator
from airfly._vendor.airflow.operators.python import PythonVirtualenvOperator


class _PythonVirtualenvDecoratedOperator(DecoratedOperator, PythonVirtualenvOperator):
    pass
