# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator
from airfly._vendor.airflow.providers.cncf.kubernetes.operators.kubernetes_pod import (
    KubernetesPodOperator,
)


class GKECreateClusterOperator(BaseOperator):
    location: "str"
    body: "typing.Union[typing.Dict, google.cloud.container_v1.types.Cluster, NoneType]"
    project_id: "typing.Union[str, NoneType]"
    gcp_conn_id: "str"
    api_version: "str"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"


class GKEDeleteClusterOperator(BaseOperator):
    name: "str"
    location: "str"
    project_id: "typing.Union[str, NoneType]"
    gcp_conn_id: "str"
    api_version: "str"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"


class GKEStartPodOperator(KubernetesPodOperator):
    location: "str"
    cluster_name: "str"
    use_internal_ip: "bool"
    project_id: "typing.Union[str, NoneType]"
    gcp_conn_id: "str"
