# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class DecoratedOperator(BaseOperator):
    python_callable: "typing.Callable"
    task_id: "str"
    op_args: "typing.Tuple[typing.Any]"
    op_kwargs: "typing.Dict[str, typing.Any]"
    multiple_outputs: "bool"
    kwargs_to_upstream: "dict"
