# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.operators.dataproc import (
    DataprocCreateClusterOperator,
    DataprocDeleteClusterOperator,
    DataprocInstantiateInlineWorkflowTemplateOperator,
    DataprocInstantiateWorkflowTemplateOperator,
    DataprocJobBaseOperator,
    DataprocScaleClusterOperator,
    DataprocSubmitHadoopJobOperator,
    DataprocSubmitHiveJobOperator,
    DataprocSubmitPigJobOperator,
    DataprocSubmitPySparkJobOperator,
    DataprocSubmitSparkJobOperator,
    DataprocSubmitSparkSqlJobOperator,
)


class DataprocClusterCreateOperator(DataprocCreateClusterOperator):
    pass


class DataprocClusterDeleteOperator(DataprocDeleteClusterOperator):
    pass


class DataprocClusterScaleOperator(DataprocScaleClusterOperator):
    pass


class DataProcHadoopOperator(DataprocSubmitHadoopJobOperator):
    pass


class DataProcHiveOperator(DataprocSubmitHiveJobOperator):
    pass


class DataProcJobBaseOperator(DataprocJobBaseOperator):
    pass


class DataProcPigOperator(DataprocSubmitPigJobOperator):
    pass


class DataProcPySparkOperator(DataprocSubmitPySparkJobOperator):
    pass


class DataProcSparkOperator(DataprocSubmitSparkJobOperator):
    pass


class DataProcSparkSqlOperator(DataprocSubmitSparkSqlJobOperator):
    pass


class DataprocWorkflowTemplateInstantiateInlineOperator(
    DataprocInstantiateInlineWorkflowTemplateOperator
):
    pass


class DataprocWorkflowTemplateInstantiateOperator(
    DataprocInstantiateWorkflowTemplateOperator
):
    pass
