# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.apache.hive.transfers.hive_to_mysql import (
    HiveToMySqlOperator,
)


class HiveToMySqlTransfer(HiveToMySqlOperator):
    pass
