# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class BigQueryToMySqlOperator(BaseOperator):
    dataset_table: "str"
    mysql_table: "str"
    selected_fields: "typing.Union[str, NoneType]"
    gcp_conn_id: "str"
    mysql_conn_id: "str"
    database: "typing.Union[str, NoneType]"
    delegate_to: "typing.Union[str, NoneType]"
    replace: "bool"
    batch_size: "int"
    location: "typing.Union[str, NoneType]"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"
