# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class SparkSubmitOperator(BaseOperator):
    application: "str"
    conf: "typing.Union[typing.Dict[str, typing.Any], NoneType]"
    conn_id: "str"
    files: "typing.Union[str, NoneType]"
    py_files: "typing.Union[str, NoneType]"
    archives: "typing.Union[str, NoneType]"
    driver_class_path: "typing.Union[str, NoneType]"
    jars: "typing.Union[str, NoneType]"
    java_class: "typing.Union[str, NoneType]"
    packages: "typing.Union[str, NoneType]"
    exclude_packages: "typing.Union[str, NoneType]"
    repositories: "typing.Union[str, NoneType]"
    total_executor_cores: "typing.Union[int, NoneType]"
    executor_cores: "typing.Union[int, NoneType]"
    executor_memory: "typing.Union[str, NoneType]"
    driver_memory: "typing.Union[str, NoneType]"
    keytab: "typing.Union[str, NoneType]"
    principal: "typing.Union[str, NoneType]"
    proxy_user: "typing.Union[str, NoneType]"
    name: "str"
    num_executors: "typing.Union[int, NoneType]"
    status_poll_interval: "int"
    application_args: "typing.Union[typing.List[typing.Any], NoneType]"
    env_vars: "typing.Union[typing.Dict[str, typing.Any], NoneType]"
    verbose: "bool"
    spark_binary: "typing.Union[str, NoneType]"
