# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.amazon.aws.transfers.google_api_to_s3 import (
    GoogleApiToS3Operator,
)


class GoogleApiToS3Transfer(GoogleApiToS3Operator):
    pass
