# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class AzureCosmosInsertDocumentOperator(BaseOperator):
    database_name: "str"
    collection_name: "str"
    document: "dict"
    azure_cosmos_conn_id: "str"
