# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.operators.vision import (
    CloudVisionCreateProductOperator,
    CloudVisionCreateProductSetOperator,
    CloudVisionCreateReferenceImageOperator,
    CloudVisionDeleteProductOperator,
    CloudVisionDeleteProductSetOperator,
    CloudVisionGetProductOperator,
    CloudVisionGetProductSetOperator,
    CloudVisionImageAnnotateOperator,
    CloudVisionTextDetectOperator,
    CloudVisionUpdateProductOperator,
    CloudVisionUpdateProductSetOperator,
)


class CloudVisionAnnotateImageOperator(CloudVisionImageAnnotateOperator):
    pass


class CloudVisionDetectDocumentTextOperator(CloudVisionTextDetectOperator):
    pass


class CloudVisionProductCreateOperator(CloudVisionCreateProductOperator):
    pass


class CloudVisionProductDeleteOperator(CloudVisionDeleteProductOperator):
    pass


class CloudVisionProductGetOperator(CloudVisionGetProductOperator):
    pass


class CloudVisionProductSetCreateOperator(CloudVisionCreateProductSetOperator):
    pass


class CloudVisionProductSetDeleteOperator(CloudVisionDeleteProductSetOperator):
    pass


class CloudVisionProductSetGetOperator(CloudVisionGetProductSetOperator):
    pass


class CloudVisionProductSetUpdateOperator(CloudVisionUpdateProductSetOperator):
    pass


class CloudVisionProductUpdateOperator(CloudVisionUpdateProductOperator):
    pass


class CloudVisionReferenceImageCreateOperator(CloudVisionCreateReferenceImageOperator):
    pass
