# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.operators.natural_language import (
    CloudNaturalLanguageAnalyzeEntitiesOperator,
    CloudNaturalLanguageAnalyzeEntitySentimentOperator,
    CloudNaturalLanguageAnalyzeSentimentOperator,
    CloudNaturalLanguageClassifyTextOperator,
)


class CloudLanguageAnalyzeEntitiesOperator(CloudNaturalLanguageAnalyzeEntitiesOperator):
    pass


class CloudLanguageAnalyzeEntitySentimentOperator(
    CloudNaturalLanguageAnalyzeEntitySentimentOperator
):
    pass


class CloudLanguageAnalyzeSentimentOperator(
    CloudNaturalLanguageAnalyzeSentimentOperator
):
    pass


class CloudLanguageClassifyTextOperator(CloudNaturalLanguageClassifyTextOperator):
    pass
