# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class DingdingOperator(BaseOperator):
    dingding_conn_id: "str"
    message_type: "str"
    message: "typing.Union[str, dict, NoneType]"
    at_mobiles: "typing.Union[typing.List[str], NoneType]"
    at_all: "bool"
