# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.sensors.base import BaseSensorOperator


class AthenaSensor(BaseSensorOperator):
    query_execution_id: "str"
    max_retries: "typing.Union[int, NoneType]"
    aws_conn_id: "str"
    sleep_time: "int"
