# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class VerticaOperator(BaseOperator):
    sql: "typing.Union[str, typing.List[str]]"
    vertica_conn_id: "str"
