# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class AzureDataLakeStorageListOperator(BaseOperator):
    path: "str"
    azure_data_lake_conn_id: "str"
