# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.transfers.cassandra_to_gcs import (
    CassandraToGCSOperator,
)


class CassandraToGoogleCloudStorageOperator(CassandraToGCSOperator):
    pass
