# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.sensors.base import BaseSensorOperator


class AwsRedshiftClusterSensor(BaseSensorOperator):
    cluster_identifier: "str"
    target_status: "str"
    aws_conn_id: "str"
