# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.amazon.aws.operators.sagemaker_base import (
    SageMakerBaseOperator,
)


class SageMakerEndpointConfigOperator(SageMakerBaseOperator):
    config: "dict"
