# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.operators.gcs import (
    GCSDeleteObjectsOperator,
)


class GoogleCloudStorageDeleteOperator(GCSDeleteObjectsOperator):
    pass
