# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class GrpcOperator(BaseOperator):
    stub_class: "typing.Callable"
    call_func: "str"
    grpc_conn_id: "str"
    data: "typing.Union[dict, NoneType]"
    interceptors: "typing.Union[typing.List[typing.Callable], NoneType]"
    custom_connection_func: "typing.Union[typing.Callable, NoneType]"
    streaming: "bool"
    response_callback: "typing.Union[typing.Callable, NoneType]"
    log_response: "bool"
