# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.operators.bigquery import (
    BigQueryDeleteTableOperator,
)


class BigQueryTableDeleteOperator(BigQueryDeleteTableOperator):
    pass
