# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.transfers.postgres_to_gcs import (
    PostgresToGCSOperator,
)


class PostgresToGoogleCloudStorageOperator(PostgresToGCSOperator):
    pass
