# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class CassandraToGCSOperator(BaseOperator):
    cql: "str"
    bucket: "str"
    filename: "str"
    schema_filename: "typing.Union[str, NoneType]"
    approx_max_file_size_bytes: "int"
    gzip: "bool"
    cassandra_conn_id: "str"
    gcp_conn_id: "str"
    google_cloud_storage_conn_id: "typing.Union[str, NoneType]"
    delegate_to: "typing.Union[str, NoneType]"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"
