# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class OpsgenieAlertOperator(BaseOperator):
    message: "str"
    opsgenie_conn_id: "str"
    alias: "typing.Union[str, NoneType]"
    description: "typing.Union[str, NoneType]"
    responders: "typing.Union[typing.List[dict], NoneType]"
    visible_to: "typing.Union[typing.List[dict], NoneType]"
    actions: "typing.Union[typing.List[str], NoneType]"
    tags: "typing.Union[typing.List[str], NoneType]"
    details: "typing.Union[dict, NoneType]"
    entity: "typing.Union[str, NoneType]"
    source: "typing.Union[str, NoneType]"
    priority: "typing.Union[str, NoneType]"
    user: "typing.Union[str, NoneType]"
    note: "typing.Union[str, NoneType]"
