# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.transfers.sql_to_gcs import (
    BaseSQLToGCSOperator,
)


class MySQLToGCSOperator(BaseSQLToGCSOperator):
    mysql_conn_id: "_empty"
    ensure_utc: "_empty"
