# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.sensors.base import BaseSensorOperator


class JiraSensor(BaseSensorOperator):
    method_name: "str"
    jira_conn_id: "str"
    method_params: "typing.Union[dict, NoneType]"
    result_processor: "typing.Union[typing.Callable, NoneType]"


class JiraTicketSensor(JiraSensor):
    jira_conn_id: "str"
    ticket_id: "typing.Union[str, NoneType]"
    field: "typing.Union[str, NoneType]"
    expected_value: "typing.Union[str, NoneType]"
    field_checker_func: "typing.Union[typing.Callable, NoneType]"
