# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class DockerOperator(BaseOperator):
    image: "str"
    api_version: "typing.Union[str, NoneType]"
    command: "typing.Union[str, typing.List[str], NoneType]"
    container_name: "typing.Union[str, NoneType]"
    cpus: "float"
    docker_url: "str"
    environment: "typing.Union[typing.Dict, NoneType]"
    private_environment: "typing.Union[typing.Dict, NoneType]"
    force_pull: "bool"
    mem_limit: "typing.Union[float, str, NoneType]"
    host_tmp_dir: "typing.Union[str, NoneType]"
    network_mode: "typing.Union[str, NoneType]"
    tls_ca_cert: "typing.Union[str, NoneType]"
    tls_client_cert: "typing.Union[str, NoneType]"
    tls_client_key: "typing.Union[str, NoneType]"
    tls_hostname: "typing.Union[str, bool, NoneType]"
    tls_ssl_version: "typing.Union[str, NoneType]"
    tmp_dir: "str"
    user: "typing.Union[str, int, NoneType]"
    mounts: "typing.Union[typing.List[docker.types.services.Mount], NoneType]"
    entrypoint: "typing.Union[str, typing.List[str], NoneType]"
    working_dir: "typing.Union[str, NoneType]"
    xcom_all: "bool"
    docker_conn_id: "typing.Union[str, NoneType]"
    dns: "typing.Union[typing.List[str], NoneType]"
    dns_search: "typing.Union[typing.List[str], NoneType]"
    auto_remove: "bool"
    shm_size: "typing.Union[int, NoneType]"
    tty: "bool"
    privileged: "bool"
    cap_add: "typing.Union[typing.Iterable[str], NoneType]"
    extra_hosts: "typing.Union[typing.Dict[str, str], NoneType]"
