# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.apache.hdfs.sensors.hdfs import (
    HdfsFolderSensor,
    HdfsRegexSensor,
)


class HdfsSensorFolder(HdfsFolderSensor):
    pass


class HdfsSensorRegex(HdfsRegexSensor):
    pass
