# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class HiveToMySqlOperator(BaseOperator):
    sql: "str"
    mysql_table: "str"
    hiveserver2_conn_id: "str"
    mysql_conn_id: "str"
    mysql_preoperator: "typing.Union[str, NoneType]"
    mysql_postoperator: "typing.Union[str, NoneType]"
    bulk_load: "bool"
    hive_conf: "typing.Union[typing.Dict, NoneType]"
