# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.sensors.bigquery import (
    BigQueryTableExistenceSensor,
)


class BigQueryTableSensor(BigQueryTableExistenceSensor):
    pass
