# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class BigQueryToGCSOperator(BaseOperator):
    source_project_dataset_table: "str"
    destination_cloud_storage_uris: "typing.List[str]"
    compression: "str"
    export_format: "str"
    field_delimiter: "str"
    print_header: "bool"
    gcp_conn_id: "str"
    bigquery_conn_id: "typing.Union[str, NoneType]"
    delegate_to: "typing.Union[str, NoneType]"
    labels: "typing.Union[typing.Dict, NoneType]"
    location: "typing.Union[str, NoneType]"
    impersonation_chain: "typing.Union[str, typing.Sequence[str], NoneType]"
