# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.http.operators.http import SimpleHttpOperator


class SlackWebhookOperator(SimpleHttpOperator):
    http_conn_id: "str"
    webhook_token: "typing.Union[str, NoneType]"
    message: "str"
    attachments: "typing.Union[list, NoneType]"
    blocks: "typing.Union[list, NoneType]"
    channel: "typing.Union[str, NoneType]"
    username: "typing.Union[str, NoneType]"
    icon_emoji: "typing.Union[str, NoneType]"
    icon_url: "typing.Union[str, NoneType]"
    link_names: "bool"
    proxy: "typing.Union[str, NoneType]"
