# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.operators.dlp import (
    CloudDLPDeleteDLPJobOperator,
    CloudDLPGetDLPJobOperator,
    CloudDLPGetDLPJobTriggerOperator,
    CloudDLPListDLPJobsOperator,
)


class CloudDLPDeleteDlpJobOperator(CloudDLPDeleteDLPJobOperator):
    pass


class CloudDLPGetDlpJobOperator(CloudDLPGetDLPJobOperator):
    pass


class CloudDLPGetJobTripperOperator(CloudDLPGetDLPJobTriggerOperator):
    pass


class CloudDLPListDlpJobsOperator(CloudDLPListDLPJobsOperator):
    pass
