# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class SimpleHttpOperator(BaseOperator):
    endpoint: "typing.Union[str, NoneType]"
    method: "str"
    data: "typing.Any"
    headers: "typing.Union[typing.Dict[str, str], NoneType]"
    response_check: "typing.Union[typing.Callable[..., bool], NoneType]"
    response_filter: "typing.Union[typing.Callable[..., typing.Any], NoneType]"
    extra_options: "typing.Union[typing.Dict[str, typing.Any], NoneType]"
    http_conn_id: "str"
    log_response: "bool"
    auth_type: "typing.Type[requests.auth.AuthBase]"
