# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.transfers.mysql_to_gcs import (
    MySQLToGCSOperator,
)


class MySqlToGoogleCloudStorageOperator(MySQLToGCSOperator):
    pass
