# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.sensors.base import BaseSensorOperator


class FTPSensor(BaseSensorOperator):
    path: "str"
    ftp_conn_id: "str"
    fail_on_transient_errors: "bool"


class FTPSSensor(FTPSensor):
    path: "str"
    ftp_conn_id: "str"
    fail_on_transient_errors: "bool"
