# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.apache.hive.transfers.vertica_to_hive import (
    VerticaToHiveOperator,
)


class VerticaToHiveTransfer(VerticaToHiveOperator):
    pass
