# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class SqliteOperator(BaseOperator):
    sql: "str"
    sqlite_conn_id: "str"
    parameters: "typing.Union[typing.Mapping, typing.Iterable, NoneType]"
