# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.transfers.mssql_to_gcs import (
    MSSQLToGCSOperator,
)


class MsSqlToGoogleCloudStorageOperator(MSSQLToGCSOperator):
    pass
