# NOTE: This file is auto-generated by "inv sync-meta"

name = "airfly"
version = "0.6.1"
description = "Auto generate Airflow's dag.py on the fly"
authors = ["ryanchao2012 <ryanchao2012@gmail.com>"]
license = "MIT"
readme = "README.md"
repository = "https://github.com/ryanchao2012/airfly"
