# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class SnowflakeOperator(BaseOperator):
    sql: "typing.Any"
    snowflake_conn_id: "str"
    parameters: "typing.Union[dict, NoneType]"
    autocommit: "bool"
    warehouse: "typing.Union[str, NoneType]"
    database: "typing.Union[str, NoneType]"
    role: "typing.Union[str, NoneType]"
    schema: "typing.Union[str, NoneType]"
    authenticator: "typing.Union[str, NoneType]"
    session_parameters: "typing.Union[dict, NoneType]"
