# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.operators.bigtable import (
    BigtableCreateInstanceOperator,
    BigtableCreateTableOperator,
    BigtableDeleteInstanceOperator,
    BigtableDeleteTableOperator,
    BigtableUpdateClusterOperator,
)
from airfly._vendor.airflow.providers.google.cloud.sensors.bigtable import (
    BigtableTableReplicationCompletedSensor,
)


class BigtableClusterUpdateOperator(BigtableUpdateClusterOperator):
    pass


class BigtableInstanceCreateOperator(BigtableCreateInstanceOperator):
    pass


class BigtableInstanceDeleteOperator(BigtableDeleteInstanceOperator):
    pass


class BigtableTableCreateOperator(BigtableCreateTableOperator):
    pass


class BigtableTableDeleteOperator(BigtableDeleteTableOperator):
    pass


class BigtableTableWaitForReplicationSensor(BigtableTableReplicationCompletedSensor):
    pass
