# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class VerticaToHiveOperator(BaseOperator):
    sql: "_empty"
    hive_table: "_empty"
    create: "_empty"
    recreate: "_empty"
    partition: "_empty"
    delimiter: "_empty"
    vertica_conn_id: "_empty"
    hive_cli_conn_id: "_empty"
