# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class RedshiftToS3Operator(BaseOperator):
    s3_bucket: "str"
    s3_key: "str"
    schema: "str"
    table: "str"
    select_query: "str"
    redshift_conn_id: "str"
    aws_conn_id: "str"
    verify: "typing.Union[bool, str, NoneType]"
    unload_options: "typing.Union[typing.List, NoneType]"
    autocommit: "bool"
    include_header: "bool"
    table_as_file_name: "bool"
