# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.transfers.gcs_to_gcs import (
    GCSToGCSOperator,
)


class GoogleCloudStorageToGoogleCloudStorageOperator(GCSToGCSOperator):
    pass
